Locale class

语言模板

Constructors

Locale({required String name, List<String> monthAbbreviations = const [], int weekStart = 0, List<String> weekAbbreviations = const [], Map<String, String> formatText = const {}, Map<String, String> otherText = const {}})
name 语言名称

Properties

formatText Map<String, String>
格式文字
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
monthAbbreviations List<String>
月份缩写数组
getter/setter pair
name String
名称
getter/setter pair
otherText Map<String, String>
其他文字 扩展的时候使用
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
weekAbbreviations List<String>
周数组
getter/setter pair
weekStart int
周缩写开始
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited